@@ -2,6 +2,7 @@ from .abstract_base_detector import AbstractBaseDetector
 from .abstract_base_generator import AbstractBaseGenerator
 from .abstract_base_model import AbstractBaseModel
 from .abstract_base_time_series import AbstractBaseTimeSeries
+from .abstract_base_types import AbstractBaseMetadataType
 from .abstract_io import (
     AbstractInput,
     AbstractOutputJson,
@@ -14,6 +15,7 @@ __all__ = [
     "AbstractBaseGenerator",
     "AbstractBaseModel",
     "AbstractBaseTimeSeries",
+    "AbstractBaseMetadataType",
     # Abstract IO
     "AbstractInput",
     "AbstractOutputJson",
