@@ -1,10 +1,10 @@
 
 def relative_error(x_0: float, x: float):
-    """
+    r"""
     Compute the relative error between two values
 
     .. math::
-        \delta x = \frac{x_0 - x}{x}
+       \Delta x = \frac{x_0 - x}{x}
 
     Args:
         x_0: float of the inferred value
@@ -18,11 +18,11 @@ def relative_error(x_0: float, x: float):
 
 
 def absolute_error(x_0: float, x: float):
-    """
+    r"""
     Compute the absolute error between two values
 
     .. math::
-        \Delta x = x_0 - x
+       \Delta x = x_0 - x
 
     Args:
         x_0: float of the inferred value
