@@ -12,7 +12,7 @@ class TimeSeriesClassificationDataset(BaseDataset):
     def __init__(self, timeseriesdataset: TimeSeriesDataset):
         super(TimeSeriesClassificationDataset, self).__init__(tsd=timeseriesdataset)
         self.data = np.array([ts.series for ts in timeseriesdataset])
-        self.labels = [ts.label for ts in timeseriesdataset]
+        self.labels = [ts.class_label for ts in timeseriesdataset]
 
     def __len__(self):
         return len(self.data)
