@@ -1,4 +1,5 @@
-from typing import NoReturn, Tuple, Any, Union, Optional, List, Callable
+from typing import NoReturn, Tuple, Any, Union, Optional, List
+from copy import deepcopy, copy
 
 from darts import TimeSeries as DartsTimeSeries
 import numpy as np
@@ -17,14 +18,17 @@ from timeatlas.config.constants import (
     METADATA_FILENAME,
     METADATA_EXT
 )
+
 from timeatlas.metadata import Metadata
 from timeatlas.processors.scaler import Scaler
-from timeatlas.plots.time_series import line_plot, status_plot
+from timeatlas.plots.time_series import line_plot
 from timeatlas.utils import ensure_dir, to_pickle
 
 
-class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
-                 AbstractOutputPickle):
+class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText, AbstractOutputPickle):
+    """
+     A TimeSeries object is a series of time indexed values.
+    """
     """Defines a time series
 
     A TimeSeries object is a series of time indexed values.
@@ -35,8 +39,16 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
     """
 
     def __init__(self, series: Union[Series, DataFrame] = None,
-                 metadata: Metadata = None, label: str or None = None):
+            metadata: Metadata = None, class_label: str or None = None):
+        """Defines a time series
 
+        A TimeSeries object is a series of time indexed values.
+
+        Args:
+            series: Series or DataFrame containing the values and labels
+            metadata: Metadata-object
+            class_label: class label
+        """
         if series is not None:
             # Check if values have a DatetimeIndex
             assert isinstance(series.index, DatetimeIndex), \
@@ -60,8 +72,8 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
 
                 # Otherwise, one column should be called "values"
                 assert TIME_SERIES_VALUES in series.columns, \
-                    "DataFrame as input series must contain a column called {}"\
-                    .format(TIME_SERIES_VALUES)
+                    "DataFrame as input series must contain a column called {}" \
+                        .format(TIME_SERIES_VALUES)
 
             # Create the TimeSeries object with certainty that values
             # are sorted by the time index
@@ -69,7 +81,7 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
 
             # Add the freq if regular
             if len(series) >= 3:
-                infer_freq(self.series.index)
+                self.series.index.freq = infer_freq(self.series.index)
 
             # Create instance variables
             self.index = self.series.index  # index accessor
@@ -77,7 +89,7 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
         else:
             self.series = None
 
-        self.label = label  # label of the TimeSeries (for classification)
+        self.class_label = class_label  # label of the TimeSeries (for classification)
 
         if metadata is not None:
             self.metadata = metadata
@@ -108,7 +120,7 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
 
     @staticmethod
     def create(start: str, end: str, freq: Union[str, 'TimeSeries'] = None,
-               metadata: Metadata = None) \
+            metadata: Metadata = None) \
             -> 'TimeSeries':
         """Creates an empty TimeSeries object with the period as index
 
@@ -130,13 +142,26 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
                            index=date_range(start, end, freq=freq))
         return TimeSeries(series, metadata)
 
-    def plot(self) -> Any:
-        """Plot a TimeSeriesDataset
+    def plot(self, *args, **kwargs) -> Any:
+        """Plot a TimeSeries
 
         Returns:
             plotly.graph_objects.Figure
         """
-        return line_plot(self)
+        return line_plot(self, *args, **kwargs)
+
+    def copy(self, deep=False) -> 'TimeSeries':
+        """Copy a TimeSeries
+
+        Copy the TSD to either a deep or shallow copy of itself
+
+        Args:
+            deep: if True, creates a deep copy else a shallow one
+
+        Returns: (deep) copy of TimeSeries
+
+        """
+        return deepcopy(self) if deep else copy(self)
 
     def split_at(self, timestamp: Union[str, Timestamp]) \
             -> Tuple['TimeSeries', 'TimeSeries']:
@@ -162,19 +187,26 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
     def split_in_chunks(self, n: int) -> List['TimeSeries']:
         """Split a TimeSeries into chunks of length n
 
+        When the number of element in the TimeSeries is not a multiple of n, the
+        last chunk will have a length smaller than n.
+
         Args:
             n: length of the chunks
 
         Returns:
             List of TimeSeries
         """
+        from timeatlas import TimeSeriesDataset
+
         ts_chunks = [TimeSeries(series=v, metadata=self.metadata) for n, v in
                      self.series.groupby(np.arange(len(self.series)) // n)]
         return ts_chunks
 
     def fill(self, value: Any) -> 'TimeSeries':
-        """Fill a TimeSeries with a value. If given a unique value, all values
-        will be broadcasted. If given an array of the length of the TimeSeries,
+        """Fill a TimeSeries with values
+
+        Fill a TimeSeries with a value. If given a unique value, all values
+        will be broadcast. If given an array of the length of the TimeSeries,
         it will replace all values.
 
         Args:
@@ -190,15 +222,17 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
     def empty(self) -> 'TimeSeries':
         """Empty the TimeSeries (fill all values with NaNs)
 
+        Replace all values of a TimeSeries with NaNs
+
         Returns:
             TimeSeries
         """
         return self.fill(np.nan)
 
-    def pad(self, limit: Union[int, str, Timestamp], side: Optional[str] = None,
-            value: Any = np.NaN):
-        """
-        Pad a TimeSeries until a given limit
+    def pad(self, limit: Union[int, str, Timestamp], side: Optional[str] = None, value: Any = np.NaN) -> 'TimeSeries':
+        """Pad a TimeSeries until a given limit
+
+        Padding a TimeSeries on left or right sides.
 
         Args:
             limit: int, str or Pandas Timestamp
@@ -217,8 +251,10 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
         Returns:
             TimeSeries
         """
+
         def create_pad(new_limit, ts, fill_val):
             """
+
             Local utility function to create padding time series from a Pandas
             Timestamp for a given TimeSeries
 
@@ -231,16 +267,16 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
                 TimeSeries
             """
             if new_limit < ts.start():
-                return ts.create(new_limit, ts.start(), freq=ts)\
+                return ts.create(new_limit, ts.start(), freq=ts) \
                            .fill(fill_val)[:-1]
             elif new_limit > ts.end():
-                return ts.create(ts.end(), new_limit, freq=ts)\
+                return ts.create(ts.end(), new_limit, freq=ts) \
                            .fill(fill_val)[1:]
             if new_limit == ts.start() or new_limit == ts.end():
                 return TimeSeries()
             else:
                 raise ValueError("The given limit is included in the time "
-                           "series, padding is impossible")
+                                 "series, padding is impossible")
 
         # Create padding TimeSeries from a given number of elements to pad with
         if isinstance(limit, int):
@@ -337,6 +373,10 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
             TimeSeries
         """
         if ts is not None:
+
+            assert len(self) == len(ts), "The length of the TimeSeries given " \
+                                         "as argument should be equal to self."
+
             s1 = self.series[TIME_SERIES_VALUES]
             s2 = ts.series[TIME_SERIES_VALUES]
             df = DataFrame(data={"s1": s1, "s2": s2})
@@ -368,12 +408,12 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
         Returns:
             TimeSeries
         """
-        # avoid duplicated indexes
+        # select all element in series that are not duplicates
         new_series = self.series[~self.series.index.duplicated()]
         new_series = new_series.asfreq(freq, method=method)
         return TimeSeries(new_series, self.metadata)
 
-    def group_by(self, freq: str, method: Optional[str] = "mean")\
+    def group_by(self, freq: str, method: Optional[str] = "mean") \
             -> 'TimeSeries':
         """Groups values by a frequency.
 
@@ -434,12 +474,20 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
 
         See https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.Series.interpolate.html
         for reference
+
+        Args:
+            *args: check pandas documentation
+            **kwargs: check pandas documentation
+
+        Returns:
+            TimeSeries
+
         """
         new_series = self.series.interpolate(*args, **kwargs)
         return TimeSeries(new_series, self.metadata)
 
     def normalize(self, method: str) -> 'TimeSeries':
-        """Normalize a Time Series with a given method
+        """Normalize a TimeSeries with a given method
 
         Args:
             method: str
@@ -450,22 +498,26 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
             TimeSeries
         """
         if method == "minmax":
-            scaled_series = Scaler.minmax(self.series)
+            scaled_series = Scaler.minmax(self)
         elif method == "zscore":
-            scaled_series = Scaler.zscore(self.series)
+            scaled_series = Scaler.zscore(self)
         else:
             raise ValueError("{} isn't recognized as a normalization method"
                              .format(method))
-        return TimeSeries(scaled_series, self.metadata)
+        return scaled_series
 
     def round(self, decimals: int) -> 'TimeSeries':
         """Round the values in the series.values
 
         Args:
             decimals: number of digits after the comma
+
+        Returns:
+            TimeSeries
+
         """
-        return TimeSeries(self.series.astype(float).round(decimals=decimals),
-                          metadata=self.metadata)
+        new_series = self.series.astype(float).round(decimals=decimals)
+        return TimeSeries(new_series, self.metadata)
 
     def sort(self, *args, **kwargs):
         """Sort a TimeSeries by time stamps
@@ -588,14 +640,15 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
         """
         return self.series.index.inferred_freq
 
-    def resolution(self) -> 'TimeSeries':
-        """Compute the time difference between each timestamp of a TimeSeries
+    def time_detlas(self) -> 'TimeSeries':
+        """Compute the time difference in seconds between each timestamp
+        of a TimeSeries
 
         Returns:
             TimeSeries
         """
-        diff = self.series.index.to_series().diff().dt.total_seconds()
-        ts = TimeSeries(DataFrame(diff, columns=[TIME_SERIES_VALUES]),
+        deltas = self.series.index.to_series().diff().dt.total_seconds()
+        ts = TimeSeries(DataFrame(deltas, columns=[TIME_SERIES_VALUES]),
                         self.metadata)
         return ts
 
@@ -603,7 +656,7 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
         """Get the duration of the TimeSeries
 
         Returns:
-            a Pandas Timedelta
+            Pandas Timedelta
         """
         start, end = self.boundaries()
         return end - start
@@ -617,18 +670,21 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
 
         Args:
             path: str of the path where the TimeSeries will be saved
+
+        Returns:
+            None
         """
         # Create the time series file
         file_path = "{}/{}.{}".format(path, TIME_SERIES_FILENAME,
                                       TIME_SERIES_EXT)
         ensure_dir(file_path)
         self.__series_to_csv(self.series, file_path)
-        if self.metadata is None and self.label is not None:
-            self.metadata = Metadata(items={'label': self.label})
+        if self.metadata is None and self.class_label is not None:
+            self.metadata = Metadata(items={'label': self.class_label})
         # Create the metadata file
         if self.metadata is not None:
-            if self.label is not None:
-                self.metadata.add({'label': self.label})
+            if self.class_label is not None:
+                self.metadata.add({'label': self.class_label})
             file_path = "{}/{}.{}".format(path, METADATA_FILENAME, METADATA_EXT)
             ensure_dir(file_path)
             self.metadata.to_json(pretty_print=True, path=file_path)
@@ -667,8 +723,7 @@ class TimeSeries(AbstractBaseTimeSeries, AbstractOutputText,
         return self.series
 
     @staticmethod
-    def __series_to_csv(series: Union[Series, DataFrame], path: str) \
-            -> NoReturn:
+    def __series_to_csv(series: Union[Series, DataFrame], path: str) -> NoReturn:
         """Export a Pandas Series or DataFrame and put it into a CSV file
 
         Args:
