@@ -5,7 +5,7 @@ from typing import List, Any, NoReturn, Tuple, Union, Optional
 from warnings import warn
 
 import numpy as np
-from pandas import DataFrame, Timestamp, Timedelta, concat
+from pandas import DataFrame, Timestamp, Timedelta
 from pandas.tseries.frequencies import to_offset
 from pandas.tseries.offsets import DateOffset
 
@@ -46,7 +46,7 @@ class TimeSeriesDataset(List,
 
     def __setitem__(self, item, value) -> NoReturn:
         if isinstance(value, TimeSeries):
-            self[item] = value
+            super().__setitem__(item, value)
         else:
             raise ValueError("Value argument must be TimeSeries")
 
@@ -100,16 +100,16 @@ class TimeSeriesDataset(List,
         else:
             super().append(item)
 
-    def plot(self) -> Any:
+    def plot(self, *args, **kwargs) -> Any:
         """Plot a TimeSeriesDataset
 
         Returns:
             plotly.graph_objects.Figure
         """
-        return line_plot(self)
+        return line_plot(self, *args, **kwargs)
 
     def copy(self, deep=True) -> 'TimeSeriesDataset':
-        """Copy a list
+        """Copy a TimeSeriesDataset
 
         Copy the TSD to either a deep or shallow copy of itself
 
@@ -192,8 +192,7 @@ class TimeSeriesDataset(List,
 
     def pad(self, limit: Union[int, str, Timestamp], side: Optional[str] = None,
             value: Any = np.NaN) -> 'TimeSeriesDataset':
-        """
-        Pad a TimeSeriesDataset until a given limit
+        """Pad a TimeSeriesDataset until a given limit
 
         Args:
             limit: int, str or Pandas Timestamp
@@ -260,7 +259,7 @@ class TimeSeriesDataset(List,
         def list_duplicates(seq: list) -> list:
             """Get label duplicates
 
-            Getting a dict of with key=ts.label and value=index in TSD
+            Getting a dict of with key=ts.class_label and value=index in TSD
 
             Args:
                 seq: list of labels
@@ -280,8 +279,7 @@ class TimeSeriesDataset(List,
 
             return duplicates
 
-        def merge_duplicates(tsd: TimeSeriesDataset, duplicates: list) \
-                -> TimeSeriesDataset:
+        def merge_duplicates(tsd: TimeSeriesDataset, duplicates: list) -> TimeSeriesDataset:
             """Merging based on duplicates
 
             Merging the TimeSeriesDataset based on the duplicate list.
@@ -298,9 +296,11 @@ class TimeSeriesDataset(List,
                 # We merge everything into the first occurrence of the label
                 # -> tsd[inds[0]]
                 base_ts = tsd[inds[0]]
+                base_label = base_ts.class_label
                 if len(inds) > 1:
                     for ind in inds[1:]:
                         base_ts = base_ts.merge(tsd[ind])
+                    base_ts.class_label = base_label
                     arr.append(base_ts)
                 else:
                     arr.append(base_ts)
@@ -313,7 +313,7 @@ class TimeSeriesDataset(List,
             merged_tsd.append(ts)
 
         # Second : Get list of tuples (label, duplicate indices)
-        tsd_labels = [ts.label for ts in merged_tsd]
+        tsd_labels = [ts.class_label for ts in merged_tsd]
         duplicates = list_duplicates(seq=tsd_labels)
 
         # Third : Merge TSD, where TS has same labels.
@@ -324,8 +324,7 @@ class TimeSeriesDataset(List,
     # TimeSeriesDataset
     # -----------------
 
-    def select_components_randomly(self, n: int, seed: int = None,
-            indices: bool = False) -> Any:
+    def select_components_randomly(self, n: int, seed: int = None, indices: bool = False) -> Any:
         """Returns a subset of the TimeSeriesDataset with randomly chosen n
         elements without replacement.
 
@@ -388,7 +387,7 @@ class TimeSeriesDataset(List,
         if inplace:
             random.shuffle(self)
         else:
-            new_tsd = self.copy()
+            new_tsd = self.copy(deep=True)
             random.shuffle(new_tsd)
             return new_tsd
 
@@ -401,12 +400,29 @@ class TimeSeriesDataset(List,
 
     def apply(self, func, tsd: 'TimeSeriesDataset' = None) \
             -> 'TimeSeriesDataset':
-        # TODO (See GitHub issue 56)
+        """Apply function specialized for TimeSeriesDataset
+
+        Check the Pandas apply function to get an idea about the role of this
+        method.
+
+        .. warning::
+            This method isn't yet implemented
+
+        Args:
+            func: function
+                Python function or NumPy ufunc to apply. If ts is given as
+                param, func must have two params in the form of f(x,y)
+
+            tsd: TimeSeriesDataset
+                The second TimeSeriesDataset if you want to make an operation on
+                two time series
+
+        Returns:
+            TimeSeriesDataset
+        """
         raise NotImplementedError
 
-    def resample(self, freq: Union[str, TimeSeries],
-            method: Optional[str] = None) \
-            -> 'TimeSeriesDataset':
+    def resample(self, freq: Union[str, TimeSeries], method: Optional[str] = None) -> 'TimeSeriesDataset':
         """Convert the TimeSeries in a TimeSeriesDataset to a specified
         frequency. Optionally provide filling method to pad/backfill missing
         values.
@@ -580,21 +596,57 @@ class TimeSeriesDataset(List,
     # ----------------
 
     def min(self) -> List[Any]:
+        """Minimum of all TimeSeries in TimeSeriesDataset
+
+        Returns:
+            List of minimums
+
+        """
         return [ts.min() for ts in self]
 
     def max(self) -> List[Any]:
+        """Maximum of all TimeSeries in TimeSeriesDataset
+
+        Returns:
+            List of maximums
+
+        """
         return [ts.max() for ts in self]
 
     def mean(self) -> List[Any]:
+        """Means of all TimeSeries in TimeSeriesDataset
+
+        Returns:
+            List of means
+
+        """
         return [ts.mean() for ts in self]
 
     def median(self) -> List[Any]:
+        """Median of all TimeSeries in TimeSeriesDataset
+
+        Returns:
+            List of medians
+
+        """
         return [ts.median() for ts in self]
 
     def kurtosis(self) -> List[Any]:
+        """Kurtosis of all TimeSeries in TimeSeriesDataset
+
+        Returns:
+            List of kurtoses
+
+        """
         return [ts.kurtosis() for ts in self]
 
     def skewness(self) -> List[Any]:
+        """Skewness of all TimeSeries in TimeSeriesDataset
+
+        Returns:
+            List of skewnesses
+
+        """
         return [ts.skewness() for ts in self]
 
     def describe(self) -> DataFrame:
@@ -659,15 +711,14 @@ class TimeSeriesDataset(List,
         """
         return [ts.frequency() for ts in self]
 
-    def resolution(self) -> 'TimeSeriesDataset':
+    def time_detlas(self) -> 'TimeSeriesDataset':
         """Compute the time difference between each timestamp for all TimeSeries
         in a TimeSeriesDataset
 
        Returns:
            TimeSeriesDataset
        """
-        return TimeSeriesDataset(
-            [ts.resolution() for ts in self])
+        return TimeSeriesDataset([ts.time_detlas() for ts in self])
 
     def duration(self) -> List[Timedelta]:
         """Get the duration for all TimeSeries in a TimeSeriesDataset
@@ -722,34 +773,28 @@ class TimeSeriesDataset(List,
 
         # get the result ready
         columns = []
-        res = self[0].to_df()
-        for i, col in enumerate(res.columns):
-            columns.append(f"{col}_{i}")
+        res = DataFrame()
         # merge the rest in the result
-        rest = self[1:]
-        for i, ts in enumerate(rest):
-            res = res.merge(ts.series, how="outer",
-                            left_index=True, right_index=True)
-            cols = ts.series.columns
+        for i, ts in enumerate(self):
+            if res.empty:
+                res = ts.to_df()
+                cols = ts.series.columns
+            else:
+                res = res.merge(ts.to_df(), how="outer",
+                                left_index=True, right_index=True)
+                cols = ts.series.columns
             for col in cols:
-                columns.append(f"{col}_{i+1}")
+                columns.append(f"{i}_{col}")
         res.columns = columns
         return res
 
     def to_array(self) -> np.ndarray:
-        """TimeSeriesData to NumpyArray [n x len(tsd)], where n is number of TimeSeries in dataset
-        # TODO Should output a warning if the ts have different length
-            (issue 56)
+        """TimeSeriesData to NumpyArray [n x len(tsd)], where n is number of
+            TimeSeries in dataset
 
-        Returns: numpy.array of shape (n x len(tsd))
-        """
-        return np.array([ts.to_array() for ts in self], dtype=object)
-
-    def to_darts(self):
-        """Convert a TimeSeriesDataset to Darts TimeSeries
+        # TODO Should output a warning if the ts have different length (issue 56)
 
         Returns:
-            Darts TimeSeries object
+            numpy.array of shape (n x len(tsd))
         """
-        # TODO issue 56
-        raise NotImplementedError
+        return np.array([ts.to_array() for ts in self], dtype=object)
